@@ -22,7 +22,7 @@ import zalando_kubectl.kube_permissions
 import zalando_kubectl.secrets
 import zalando_kubectl.traffic
 import zalando_kubectl.utils as utils
-from clickclick import Action, info, print_table
+from clickclick import Action, info, print_table, OutputFormat
 from dateutil.parser import parse
 from dateutil.tz import tzutc
 from zalando_kubectl.models.deployment import Deployment
@@ -908,8 +908,11 @@ def approve_access_request(env: Environment, username):
 
 
 @cluster_access.command("list")
+@click.option(
+    "-o", "--output", type=click.Choice(["text", "json"]), default="text", help="Command output format (default: text)"
+)
 @click.pass_obj
-def list_cluster_requests(env: Environment):
+def list_cluster_requests(env: Environment, output):
     """List all current pending/approved access requests for the cluster"""
     cluster_access_check_environment(env)
 
@@ -928,12 +931,13 @@ def list_cluster_requests(env: Environment):
         request["status"] = status
         rows.append(request)
 
-    print_table(
-        ["access_type", "user", "reason", "status", "expires_in"],
-        rows,
-        styles=STYLES,
-        max_column_widths=MAX_COLUMN_WIDTHS,
-    )
+    with OutputFormat(output):
+        print_table(
+            ["access_type", "user", "reason", "status", "expires_in"],
+            rows,
+            styles=STYLES,
+            max_column_widths=MAX_COLUMN_WIDTHS,
+        )
 
 
 @click_cli.command("restart-pods", help="Restart all pods in a deployment.")
