@@ -35,6 +35,10 @@ class BlueGreen:
         return traffic
 
     def set_traffic_weight(self, stack_name: str, weight: float):
+        stackset_name = self.get_name()
+        if not stack_name.startswith(stackset_name):
+            stack_name = stackset_name + "-" + stack_name
+
         self.validate_traffic_weight(stack_name, weight)
 
         new_weights = {stack_name: weight}
